Generate a nicely formatted summary statistics table for numeric variables
See also
Other utilities:
example_data(),
export_h5ad(),
format_file_size(),
format_with_commas(),
gene_report(),
strip_plotly()
Generate a nicely formatted summary statistics table for numeric variables
Other utilities:
example_data(),
export_h5ad(),
format_file_size(),
format_with_commas(),
gene_report(),
strip_plotly()