Skip to contents

Uses the DAG to identify the minimal sufficient adjustment set for estimating the causal effect of `exposure` on `outcome`.

Usage

get_adjustment_sets(
  exposure = "cytogenetic_risk",
  outcome = "overall_survival",
  dag = NULL
)

Arguments

exposure

Character. The exposure variable name in the DAG.

outcome

Character. The outcome variable name in the DAG.

dag

A `dagitty` DAG object. Defaults to [commpass_dag()].

Value

A list of character vectors, each a minimal sufficient adjustment set.