Skip to contents

Returns a tibble documenting all known variables in the CoMMpass dataset, including clinical, biospecimen, and RNA-seq data. Each variable includes its category, data type, units, description, typical range, and a link to the GDC data dictionary.

Usage

get_commpass_data_dictionary()

Value

A tibble with columns: variable, category, data_type, units, description, typical_range, gdc_link

See also

Other data-dictionary: get_variable_docs()

Examples

dd <- get_commpass_data_dictionary()
# Filter to clinical variables
dplyr::filter(dd, category == "clinical")
#> # A tibble: 19 × 7
#>    variable          category data_type units description typical_range gdc_link
#>    <chr>             <chr>    <chr>     <chr> <chr>       <chr>         <chr>   
#>  1 submitter_id      clinical character NA    Patient id… MMRF_0001 to… https:/…
#>  2 project_id        clinical character NA    GDC projec… MMRF-COMMPASS https:/…
#>  3 age_at_diagnosis  clinical integer   days  Age at pri… 10000-35000 … https:/…
#>  4 gender            clinical character NA    Patient se… female, male… https:/…
#>  5 race              clinical character NA    Patient ra… white, black… https:/…
#>  6 ethnicity         clinical character NA    Patient et… not hispanic… https:/…
#>  7 vital_status      clinical character NA    Patient vi… Alive, Dead,… https:/…
#>  8 days_to_death     clinical integer   days  Number of … 0-5000+       https:/…
#>  9 days_to_last_fol… clinical integer   days  Number of … 0-5000+       https:/…
#> 10 primary_diagnosis clinical character NA    ICD-O-3 mo… Plasma cell … https:/…
#> 11 disease_type      clinical character NA    Type of di… Multiple Mye… https:/…
#> 12 site_of_resectio… clinical character NA    Anatomic s… Bone marrow,… https:/…
#> 13 tissue_or_organ_… clinical character NA    Anatomic s… Bone marrow   https:/…
#> 14 year_of_diagnosis clinical integer   year  Calendar y… 2005-2020     https:/…
#> 15 classification_o… clinical character NA    Tumor clas… primary, rec… https:/…
#> 16 prior_malignancy  clinical character NA    Whether pa… yes, no, not… https:/…
#> 17 prior_treatment   clinical character NA    Whether pa… yes, no, not… https:/…
#> 18 ajcc_staging_sys… clinical character NA    AJCC stagi… various edit… https:/…
#> 19 days_to_last_kno… clinical integer   days  Days from … 0-5000+       https:/…