Creates a summary table showing the number of significant genes per DE method.
See also
Other differential-expression:
compute_pca(),
plot_heatmap_de(),
plot_ma(),
plot_pca(),
plot_volcano(),
run_deseq2(),
run_vst()
Creates a summary table showing the number of significant genes per DE method.
Other differential-expression:
compute_pca(),
plot_heatmap_de(),
plot_ma(),
plot_pca(),
plot_volcano(),
run_deseq2(),
run_vst()