Downloads a subset of RNA-seq files from the public MMRF CoMMpass S3 bucket. This function is useful for testing and development with a small sample of data before downloading the full dataset. Files are downloaded using anonymous access to the public bucket.
See also
Other data-acquisition:
acquire_commpass_data(),
download_clinical_data(),
download_gdc_rnaseq(),
get_commpass_clinical(),
list_s3_commpass(),
query_commpass_rna()
Examples
if (FALSE) { # \dontrun{
# List available files
s3_files <- list_s3_commpass()
# Download first 3 RNA-seq files
downloaded <- download_s3_subset(s3_files, n = 3)
# Check what was downloaded
basename(downloaded)
} # }